==> haskell-tamarin-prover-sapic-1.10.0-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-sapic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-sapic
version:              1.10.0
visibility:           public
id:                   tamarin-prover-sapic-1.10.0-359VkfVrFeU2Nv9rJlzIBe
key:                  tamarin-prover-sapic-1.10.0-359VkfVrFeU2Nv9rJlzIBe
license:              LicenseRef-GPL
copyright:
    Robert Künnemann, Alexander Dax, CISPA-Helmholtz-Centre Saarbrücken, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Alexander Dax <alexander.dax@cispa.saarland>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for input processes in SAPIC calculus for the tamarin prover.

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides a translation from processes stated in the SAPIC calculus into multiset rewrite rules.

category:             Theorem Provers
abi:                  783ddd1df6d00fd0586001d061899692
exposed:              True
exposed-modules:
    Sapic Sapic.Annotation Sapic.Basetranslation Sapic.Bindings
    Sapic.Compression Sapic.Exceptions Sapic.Facts Sapic.LetDestructors
    Sapic.Locks Sapic.ProcessUtils Sapic.ProgressFunction
    Sapic.ProgressTranslation Sapic.ReliableChannelTranslation
    Sapic.Report Sapic.SecretChannels Sapic.States Sapic.Typing
    Sapic.Warnings

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tamarin-prover-sapic-1.10.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tamarin-prover-sapic-1.10.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tamarin-prover-sapic-1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-sapic
hs-libraries:         HStamarin-prover-sapic-1.10.0-359VkfVrFeU2Nv9rJlzIBe
depends:
    aeson-2.1.2.1-JtwfP0wSn8NCfmI6cbJvU2
    aeson-pretty-0.8.10-6GwmvpHUIXv86raeMkA2OH base-4.17.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    dlist-1.0-I6FB5Nlk17hG16fxQzZSEb exceptions-0.10.5
    fclabels-2.0.5.1-HJBmTrMyzqJJlogHHfLWKs mtl-2.2.2
    parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy parsec-3.1.16.1
    process-1.6.18.0 raw-strings-qq-1.1-5c0fuHz8OpaCWras0U8UIC
    safe-0.3.21-1ogZvSuXPXMI4tTMqSRGv5
    tamarin-prover-term-1.10.0-AUBXAb5gSpI4AT5kdTC7ud
    tamarin-prover-theory-1.10.0-B3HrREtIlkZ1sTCIEpRDWl
    tamarin-prover-utils-1.10.0-HULMJE1sbEB13hvWRtz6Rp text-2.0.2
    transformers-0.5.6.2 uniplate-1.6.13-7J8Mq4NoOs41BKvmghODLs

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-sapic/html/tamarin-prover-sapic.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-sapic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-sapic-1.10.0-42-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-sapic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-sapic
version:              1.10.0
visibility:           public
id:                   tamarin-prover-sapic-1.10.0-IBYIXg67l9nKFYiDilHDQy
key:                  tamarin-prover-sapic-1.10.0-IBYIXg67l9nKFYiDilHDQy
license:              LicenseRef-GPL
copyright:
    Robert Künnemann, Alexander Dax, CISPA-Helmholtz-Centre Saarbrücken, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Alexander Dax <alexander.dax@cispa.saarland>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for input processes in SAPIC calculus for the tamarin prover.

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides a translation from processes stated in the SAPIC calculus into multiset rewrite rules.

category:             Theorem Provers
abi:                  8da2ff2a237a311ef683a09d72fae80c
exposed:              True
exposed-modules:
    Sapic Sapic.Annotation Sapic.Basetranslation Sapic.Bindings
    Sapic.Compression Sapic.Exceptions Sapic.Facts Sapic.LetDestructors
    Sapic.Locks Sapic.ProcessUtils Sapic.ProgressFunction
    Sapic.ProgressTranslation Sapic.ReliableChannelTranslation
    Sapic.Report Sapic.SecretChannels Sapic.States Sapic.Typing
    Sapic.Warnings

import-dirs:          /usr/lib/ghc-9.4.8/site-local/tamarin-prover-sapic-1.10.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tamarin-prover-sapic-1.10.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tamarin-prover-sapic-1.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-sapic
hs-libraries:         HStamarin-prover-sapic-1.10.0-IBYIXg67l9nKFYiDilHDQy
depends:
    aeson-2.1.2.1-6acn88DzD1XA00qNRJAJcm
    aeson-pretty-0.8.10-9Vy656m0aTg7WjXe03YS1S base-4.17.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    dlist-1.0-I6FB5Nlk17hG16fxQzZSEb exceptions-0.10.5
    fclabels-2.0.5.1-tWuQkopS0Q1HcFSA7iwWT mtl-2.2.2
    parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy parsec-3.1.16.1
    process-1.6.18.0 raw-strings-qq-1.1-5c0fuHz8OpaCWras0U8UIC
    safe-0.3.21-1cfKzbT7BvNI1gm17QusEM
    tamarin-prover-term-1.10.0-53wcqnufbPj9xMpXwdHTeP
    tamarin-prover-theory-1.10.0-AOugNgqjF2mEwvZ4Uu24oU
    tamarin-prover-utils-1.10.0-DTLn1SbRrWyAyjQTIRcpd4 text-2.0.2
    transformers-0.5.6.2 uniplate-1.6.13-3t4NeuKPUknBzYHBQ5ITf

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-sapic/html/tamarin-prover-sapic.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-sapic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
